Module oqtant.tests.integration.test_oqtant_client
==================================================

Functions
---------


`test_get_job_inputs_for_job_that_doesnt_exist(oqtant_client)`
:


`test_get_job_inputs_with_run_value_that_doesnt_exist(settings, oqtant_client)`
:


`test_get_job_limits(oqtant_client)`
:


`test_get_job_that_doesnt_exist(oqtant_client)`
:


`test_get_job_while_not_authorized(oqtant_client)`
:


`test_instantiate_api(oqtant_client)`
:


`test_load_job_from_id_that_doesnt_exist(oqtant_client)`
:


`test_run_jobs_barrier(settings, oqtant_client)`
:


`test_run_jobs_bec(settings, oqtant_client)`
:


`test_run_jobs_mix(settings, oqtant_client)`
:


`test_submit_job_barrier_multiple_input(settings, oqtant_client)`
:


`test_submit_job_barrier_single_input(settings, oqtant_client)`
:


`test_submit_job_bec_multiple_input(settings, oqtant_client)`
:


`test_submit_job_bec_single_input(settings, oqtant_client)`
:


`test_submit_job_bec_single_input_get_not_output_response(settings, oqtant_client)`
:


`test_submit_job_while_not_authorized(oqtant_client)`
:
